==> 0.0.2.tar.gz: lib/resource/serializer.dart <==
part of arasu.resource;

class Serializer {
 
  static Map encode(dynamic obj){
    Map map = new Map();
    InstanceMirror im = reflect(obj);
//    ClassMirror cm = im.type;
    declarations(im.type).forEach((dm) {
      var key = MirrorSystem.getName(dm.simpleName);
      var val = im.getField(dm.simpleName).reflectee;
      if(val.runtimeType!=Null) map[key] = val.toString();
    });
    return map;
  }
  
  static String encodeWithAttr(dynamic obj,{String key: 'attr'})=> JSON.encode({key:encode(obj)});
  
  static dynamic decode(Map json,dynamic obj) {

    InstanceMirror im = reflect(obj);
    //ClassMirror cm = im.type;
    var decls = declarations(im.type);
    Map<String,VariableMirror> vars = new Map<String,VariableMirror>();
    List<String> commonKeys = common(json.keys.toList(), 
        decls.map((e){
      String name = MirrorSystem.getName(e.simpleName);
      vars[name] = e;
      return name;
      }).toList()
    );
    commonKeys.forEach((e){
      ClassMirror cm = vars[e].type as ClassMirror;
      String typeString = cm.reflectedType.toString();
      var value=json[e];

        switch (typeString) {
          case 'int':
            if(json[e].runtimeType.toString()!='int'){
              value = int.parse(json[e], onError: (_) => 0);
            }
            break;
          case 'String':
            if(json[e].runtimeType.toString()!='String'){
              value = json[e].toString();
            }            
            break;
          case 'bool':
            if(json[e].runtimeType.toString()!='bool'){
              value = ['1','true',true,1].contains(json[e]);
            }            
            break;
          case 'DateTime':
            if(json[e].runtimeType.toString()!='DateTime'){
              if(json[e].length>24){
                json[e]=json[e].substring(0,24);
              } 
              value =DateTime.parse(json[e]) ;
            }            
            break;
          case 'num':
            if(json[e].runtimeType.toString()!='int'){
              value = int.parse(json[e], onError: (_) => 0);
            }
            break;
          default:
            //print('other');
        }
      im.setField(new Symbol(e), value);
    });
    obj.attributes = encode(obj);
    return obj;
  }
  static List<String> common(List<String> a,List<String> b) {
    List<String> c = new List<String>();
    a.forEach((e){ if (b.contains(e)){ c.add(e);}});
    return c;
  }
  static Map subtractMapChanges(Map a,b){
    Map r = new Map();
    a.keys.forEach((e){ if(a[e]!=b[e]) r[e]=a[e]; });
    return r;
  }

  static Iterable<DeclarationMirror> declarations(ClassMirror cm) => cm.declarations.values.where((dm) => dm is VariableMirror && !dm.isConst && !dm.isFinal && !dm.isPrivate && !dm.isStatic && !dm.isTopLevel);
  
}

//static Map<String,dynamic> dirtyAttrs(var dirty, orig) {
//  Map<String,dynamic> attrs = new Map<String,dynamic>();
//  InstanceMirror dim = reflect(dirty);
//  InstanceMirror oim = reflect(orig);
//  
//  var ddecls = declarations(dim.type);
//  var odecls = declarations(oim.type);
//  
//  ddecls.forEach((dm) {
//    DeclarationMirror om = odecls.firstWhere((e)=>e==dm);
//    if (om!=null){
//      var key = MirrorSystem.getName(dm.simpleName);
//      var dval = dim.getField(dm.simpleName).reflectee;
//      var oval = oim.getField(om.simpleName).reflectee;
//      if (dval!=oval) {
//        attrs[key] = dval.toString();
//      }
//    }
//  });
//  return attrs;
//}

==> 0.0.6.tar.gz: lib/resource/serializer.dart <==
part of arasu.resource;

class Serializer {
 
//  static Map encode(dynamic obj){
//    Map map = new Map();
//    InstanceMirror im = reflect(obj);
////    ClassMirror cm = im.type;
//    declarations(im.type).forEach((dm) {
//      var key = MirrorSystem.getName(dm.simpleName);
//      var val = im.getField(dm.simpleName).reflectee;
//      if(val.runtimeType!=Null) map[key] = val.toString();
//    });
//    return map;
//  }
//  
//  static String encodeWithAttr(dynamic obj,{String key: 'attr'})=> JSON.encode({key:encode(obj)});
//  
  static dynamic decode(Map json,dynamic obj) {

    InstanceMirror im = reflect(obj);
    //ClassMirror cm = im.type;
    var decls = declarations(im.type);
    Map<String,VariableMirror> vars = new Map<String,VariableMirror>();
    List<String> commonKeys = common(json.keys.toList(), 
        decls.map((e){
      String name = MirrorSystem.getName(e.simpleName);
      vars[name] = e;
      return name;
      }).toList()
    );
    commonKeys.forEach((e){
      ClassMirror cm = vars[e].type as ClassMirror;
      String typeString = cm.reflectedType.toString();
      var value=json[e];

        switch (typeString) {
          case 'int':
            if(json[e].runtimeType.toString()!='int'){
              value = int.parse(json[e], onError: (_) => 0);
            }
            break;
          case 'String':
            if(json[e].runtimeType.toString()!='String'){
              value = json[e].toString();
            }            
            break;
          case 'bool':
            if(json[e].runtimeType.toString()!='bool'){
              value = ['1','true',true,1].contains(json[e]);
            }            
            break;
          case 'DateTime':
            if(json[e].runtimeType.toString()!='DateTime'){
              if(json[e].length>24){
                json[e]=json[e].substring(0,24);
              } 
              value =DateTime.parse(json[e]) ;
            }            
            break;
          case 'num':
            if(json[e].runtimeType.toString()!='int'){
              value = int.parse(json[e], onError: (_) => 0);
            }
            break;
          default:
            //print('other');
        }
      im.setField(new Symbol(e), value);
    });
    obj.attributes = obj.encode();
    return obj;
  }
  static List<String> common(List<String> a,List<String> b) {
    List<String> c = new List<String>();
    a.forEach((e){ if (b.contains(e)){ c.add(e);}});
    return c;
  }
  static Map subtractMapChanges(Map a,b){
    Map r = new Map();
    a.keys.forEach((e){ if(a[e]!=b[e]) r[e]=a[e]; });
    return r;
  }

  static Iterable<DeclarationMirror> declarations(ClassMirror cm) => cm.declarations.values.where((dm) => dm is VariableMirror && !dm.isConst && !dm.isFinal && !dm.isPrivate && !dm.isStatic && !dm.isTopLevel);
  
}

//static Map<String,dynamic> dirtyAttrs(var dirty, orig) {
//  Map<String,dynamic> attrs = new Map<String,dynamic>();
//  InstanceMirror dim = reflect(dirty);
//  InstanceMirror oim = reflect(orig);
//  
//  var ddecls = declarations(dim.type);
//  var odecls = declarations(oim.type);
//  
//  ddecls.forEach((dm) {
//    DeclarationMirror om = odecls.firstWhere((e)=>e==dm);
//    if (om!=null){
//      var key = MirrorSystem.getName(dm.simpleName);
//      var dval = dim.getField(dm.simpleName).reflectee;
//      var oval = oim.getField(om.simpleName).reflectee;
//      if (dval!=oval) {
//        attrs[key] = dval.toString();
//      }
//    }
//  });
//  return attrs;
//}
